=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-09-14 04:10:40 +0000
+++ bzrlib/errors.py	2006-09-14 05:35:04 +0000
@@ -132,9 +132,10 @@
             if isinstance(s, unicode):
                 return s.encode('utf8')
             return s
-        except (NameError, ValueError, KeyError), e:
-            return 'Unprintable exception %s: %s' \
-                % (self.__class__.__name__, str(e))
+        except (TypeError, NameError, ValueError, KeyError), e:
+            return 'Unprintable exception %s(%r): %s' \
+                % (self.__class__.__name__,
+                   self.__dict__, str(e))
 
 
 class BzrCheckError(BzrNewError):

=== modified file 'bzrlib/tests/test_errors.py'
--- bzrlib/tests/test_errors.py	2006-09-07 07:31:51 +0000
+++ bzrlib/tests/test_errors.py	2006-09-14 05:51:28 +0000
@@ -61,6 +61,10 @@
         errors.BzrNewError.__init__(self, foo=foo, bar=bar)
 
 
+class ErrorWithBadFormat(errors.BzrNewError):
+    """One format specifier: %(thing)s"""
+
+
 class TestErrorFormatting(TestCase):
     
     def test_always_str(self):
@@ -72,3 +76,12 @@
         # returned from e.__str__(), and it has non ascii characters
         s = str(e)
         self.assertEqual('Pass through \xc2\xb5 and bar', s)
+
+    def test_mismatched_format_args(self):
+        # Even though ErrorWithBadFormat's format string does not match the
+        # arguments we constructing it with, we can still stringify an instance
+        # of this exception. The resulting string will say its unprintable.
+        e = ErrorWithBadFormat(not_thing='x')
+        self.assertStartsWith(
+            str(e), 'Unprintable exception ErrorWithBadFormat(')
+

